from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="UserRegister")


@_attrs_define
class UserRegister:
    """
    Attributes:
        email (str):
        password (str):
        full_name (Union[None, Unset, str]):
    """

    email: str
    password: str
    full_name: Union[None, Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        email = self.email

        password = self.password

        full_name: Union[None, Unset, str]
        if isinstance(self.full_name, Unset):
            full_name = UNSET
        else:
            full_name = self.full_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "email": email,
                "password": password,
            }
        )
        if full_name is not UNSET:
            field_dict["full_name"] = full_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        email = d.pop("email")

        password = d.pop("password")

        def _parse_full_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        full_name = _parse_full_name(d.pop("full_name", UNSET))

        user_register = cls(
            email=email,
            password=password,
            full_name=full_name,
        )

        user_register.additional_properties = d
        return user_register

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="AgentMessageItemPublic")


@_attrs_define
class AgentMessageItemPublic:
    """
    Attributes:
        agent_id (str):
        content (Union[None, Unset, str]):
        role (Union[None, Unset, str]):  Default: 'user'.
        msg_ypte (Union[None, Unset, str]):  Default: 'msg'.
    """

    agent_id: str
    content: Union[None, Unset, str] = UNSET
    role: Union[None, Unset, str] = "user"
    msg_ypte: Union[None, Unset, str] = "msg"
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        agent_id = self.agent_id

        content: Union[None, Unset, str]
        if isinstance(self.content, Unset):
            content = UNSET
        else:
            content = self.content

        role: Union[None, Unset, str]
        if isinstance(self.role, Unset):
            role = UNSET
        else:
            role = self.role

        msg_ypte: Union[None, Unset, str]
        if isinstance(self.msg_ypte, Unset):
            msg_ypte = UNSET
        else:
            msg_ypte = self.msg_ypte

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "agent_id": agent_id,
            }
        )
        if content is not UNSET:
            field_dict["content"] = content
        if role is not UNSET:
            field_dict["role"] = role
        if msg_ypte is not UNSET:
            field_dict["msg_ypte"] = msg_ypte

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        agent_id = d.pop("agent_id")

        def _parse_content(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        content = _parse_content(d.pop("content", UNSET))

        def _parse_role(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        role = _parse_role(d.pop("role", UNSET))

        def _parse_msg_ypte(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        msg_ypte = _parse_msg_ypte(d.pop("msg_ypte", UNSET))

        agent_message_item_public = cls(
            agent_id=agent_id,
            content=content,
            role=role,
            msg_ypte=msg_ypte,
        )

        agent_message_item_public.additional_properties = d
        return agent_message_item_public

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.runnable_config_configurable import RunnableConfigConfigurable
    from ..models.runnable_config_metadata import RunnableConfigMetadata


T = TypeVar("T", bound="RunnableConfig")


@_attrs_define
class RunnableConfig:
    """Configuration for a Runnable.

    Attributes:
        tags (Union[Unset, List[str]]):
        metadata (Union[Unset, RunnableConfigMetadata]):
        callbacks (Union[Any, List[Any], None, Unset]):
        run_name (Union[Unset, str]):
        max_concurrency (Union[None, Unset, int]):
        recursion_limit (Union[Unset, int]):
        configurable (Union[Unset, RunnableConfigConfigurable]):
        run_id (Union[None, Unset, str]):
    """

    tags: Union[Unset, List[str]] = UNSET
    metadata: Union[Unset, "RunnableConfigMetadata"] = UNSET
    callbacks: Union[Any, List[Any], None, Unset] = UNSET
    run_name: Union[Unset, str] = UNSET
    max_concurrency: Union[None, Unset, int] = UNSET
    recursion_limit: Union[Unset, int] = UNSET
    configurable: Union[Unset, "RunnableConfigConfigurable"] = UNSET
    run_id: Union[None, Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        tags: Union[Unset, List[str]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags

        metadata: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        callbacks: Union[Any, List[Any], None, Unset]
        if isinstance(self.callbacks, Unset):
            callbacks = UNSET
        elif isinstance(self.callbacks, list):
            callbacks = self.callbacks

        else:
            callbacks = self.callbacks

        run_name = self.run_name

        max_concurrency: Union[None, Unset, int]
        if isinstance(self.max_concurrency, Unset):
            max_concurrency = UNSET
        else:
            max_concurrency = self.max_concurrency

        recursion_limit = self.recursion_limit

        configurable: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.configurable, Unset):
            configurable = self.configurable.to_dict()

        run_id: Union[None, Unset, str]
        if isinstance(self.run_id, Unset):
            run_id = UNSET
        else:
            run_id = self.run_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if tags is not UNSET:
            field_dict["tags"] = tags
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if callbacks is not UNSET:
            field_dict["callbacks"] = callbacks
        if run_name is not UNSET:
            field_dict["run_name"] = run_name
        if max_concurrency is not UNSET:
            field_dict["max_concurrency"] = max_concurrency
        if recursion_limit is not UNSET:
            field_dict["recursion_limit"] = recursion_limit
        if configurable is not UNSET:
            field_dict["configurable"] = configurable
        if run_id is not UNSET:
            field_dict["run_id"] = run_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.runnable_config_configurable import RunnableConfigConfigurable
        from ..models.runnable_config_metadata import RunnableConfigMetadata

        d = src_dict.copy()
        tags = cast(List[str], d.pop("tags", UNSET))

        _metadata = d.pop("metadata", UNSET)
        metadata: Union[Unset, RunnableConfigMetadata]
        if isinstance(_metadata, Unset):
            metadata = UNSET
        else:
            metadata = RunnableConfigMetadata.from_dict(_metadata)

        def _parse_callbacks(data: object) -> Union[Any, List[Any], None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                callbacks_type_0 = cast(List[Any], data)

                return callbacks_type_0
            except:  # noqa: E722
                pass
            return cast(Union[Any, List[Any], None, Unset], data)

        callbacks = _parse_callbacks(d.pop("callbacks", UNSET))

        run_name = d.pop("run_name", UNSET)

        def _parse_max_concurrency(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        max_concurrency = _parse_max_concurrency(d.pop("max_concurrency", UNSET))

        recursion_limit = d.pop("recursion_limit", UNSET)

        _configurable = d.pop("configurable", UNSET)
        configurable: Union[Unset, RunnableConfigConfigurable]
        if isinstance(_configurable, Unset):
            configurable = UNSET
        else:
            configurable = RunnableConfigConfigurable.from_dict(_configurable)

        def _parse_run_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        run_id = _parse_run_id(d.pop("run_id", UNSET))

        runnable_config = cls(
            tags=tags,
            metadata=metadata,
            callbacks=callbacks,
            run_name=run_name,
            max_concurrency=max_concurrency,
            recursion_limit=recursion_limit,
            configurable=configurable,
            run_id=run_id,
        )

        runnable_config.additional_properties = d
        return runnable_config

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.runnable_config import RunnableConfig


T = TypeVar("T", bound="ChatInput")


@_attrs_define
class ChatInput:
    """完整对话记录,(TODO:数据结构有待完善)

    Attributes:
        agent_id (str):
        config (RunnableConfig): Configuration for a Runnable.
        title (Union[None, Unset, str]):  Default: ''.
        description (Union[None, Unset, str]):  Default: ''.
        path (Union[None, Unset, str]):  Default: ''.
        share_path (Union[None, Unset, str]):  Default: ''.
        id (Union[Unset, str]):
        user_id (Union[Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
        output (Union[None, Unset, str]):  Default: ''.
    """

    agent_id: str
    config: "RunnableConfig"
    title: Union[None, Unset, str] = ""
    description: Union[None, Unset, str] = ""
    path: Union[None, Unset, str] = ""
    share_path: Union[None, Unset, str] = ""
    id: Union[Unset, str] = UNSET
    user_id: Union[Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    output: Union[None, Unset, str] = ""
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        agent_id = self.agent_id

        config = self.config.to_dict()

        title: Union[None, Unset, str]
        if isinstance(self.title, Unset):
            title = UNSET
        else:
            title = self.title

        description: Union[None, Unset, str]
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        path: Union[None, Unset, str]
        if isinstance(self.path, Unset):
            path = UNSET
        else:
            path = self.path

        share_path: Union[None, Unset, str]
        if isinstance(self.share_path, Unset):
            share_path = UNSET
        else:
            share_path = self.share_path

        id = self.id

        user_id = self.user_id

        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        output: Union[None, Unset, str]
        if isinstance(self.output, Unset):
            output = UNSET
        else:
            output = self.output

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "agent_id": agent_id,
                "config": config,
            }
        )
        if title is not UNSET:
            field_dict["title"] = title
        if description is not UNSET:
            field_dict["description"] = description
        if path is not UNSET:
            field_dict["path"] = path
        if share_path is not UNSET:
            field_dict["share_path"] = share_path
        if id is not UNSET:
            field_dict["id"] = id
        if user_id is not UNSET:
            field_dict["user_id"] = user_id
        if created_at is not UNSET:
            field_dict["created_at"] = created_at
        if updated_at is not UNSET:
            field_dict["updated_at"] = updated_at
        if output is not UNSET:
            field_dict["output"] = output

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.runnable_config import RunnableConfig

        d = src_dict.copy()
        agent_id = d.pop("agent_id")

        config = RunnableConfig.from_dict(d.pop("config"))

        def _parse_title(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        title = _parse_title(d.pop("title", UNSET))

        def _parse_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        description = _parse_description(d.pop("description", UNSET))

        def _parse_path(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        path = _parse_path(d.pop("path", UNSET))

        def _parse_share_path(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        share_path = _parse_share_path(d.pop("share_path", UNSET))

        id = d.pop("id", UNSET)

        user_id = d.pop("user_id", UNSET)

        _created_at = d.pop("created_at", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updated_at", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        def _parse_output(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        output = _parse_output(d.pop("output", UNSET))

        chat_input = cls(
            agent_id=agent_id,
            config=config,
            title=title,
            description=description,
            path=path,
            share_path=share_path,
            id=id,
            user_id=user_id,
            created_at=created_at,
            updated_at=updated_at,
            output=output,
        )

        chat_input.additional_properties = d
        return chat_input

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.blog_writer_agent_state_messages_type_0_item import BlogWriterAgentStateMessagesType0Item


T = TypeVar("T", bound="BlogWriterAgentState")


@_attrs_define
class BlogWriterAgentState:
    """
    Attributes:
        subjects (Union[List[str], None, Unset]):
        jokes (Union[List[str], None, Unset]):
        best_selected_joke (Union[None, Unset, str]):
        messages (Union[List['BlogWriterAgentStateMessagesType0Item'], None, Unset]):
        ask_human (Union[Unset, bool]):  Default: False.
    """

    subjects: Union[List[str], None, Unset] = UNSET
    jokes: Union[List[str], None, Unset] = UNSET
    best_selected_joke: Union[None, Unset, str] = UNSET
    messages: Union[List["BlogWriterAgentStateMessagesType0Item"], None, Unset] = UNSET
    ask_human: Union[Unset, bool] = False
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        subjects: Union[List[str], None, Unset]
        if isinstance(self.subjects, Unset):
            subjects = UNSET
        elif isinstance(self.subjects, list):
            subjects = self.subjects

        else:
            subjects = self.subjects

        jokes: Union[List[str], None, Unset]
        if isinstance(self.jokes, Unset):
            jokes = UNSET
        elif isinstance(self.jokes, list):
            jokes = self.jokes

        else:
            jokes = self.jokes

        best_selected_joke: Union[None, Unset, str]
        if isinstance(self.best_selected_joke, Unset):
            best_selected_joke = UNSET
        else:
            best_selected_joke = self.best_selected_joke

        messages: Union[List[Dict[str, Any]], None, Unset]
        if isinstance(self.messages, Unset):
            messages = UNSET
        elif isinstance(self.messages, list):
            messages = []
            for messages_type_0_item_data in self.messages:
                messages_type_0_item = messages_type_0_item_data.to_dict()
                messages.append(messages_type_0_item)

        else:
            messages = self.messages

        ask_human = self.ask_human

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if subjects is not UNSET:
            field_dict["subjects"] = subjects
        if jokes is not UNSET:
            field_dict["jokes"] = jokes
        if best_selected_joke is not UNSET:
            field_dict["best_selected_joke"] = best_selected_joke
        if messages is not UNSET:
            field_dict["messages"] = messages
        if ask_human is not UNSET:
            field_dict["ask_human"] = ask_human

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.blog_writer_agent_state_messages_type_0_item import BlogWriterAgentStateMessagesType0Item

        d = src_dict.copy()

        def _parse_subjects(data: object) -> Union[List[str], None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                subjects_type_0 = cast(List[str], data)

                return subjects_type_0
            except:  # noqa: E722
                pass
            return cast(Union[List[str], None, Unset], data)

        subjects = _parse_subjects(d.pop("subjects", UNSET))

        def _parse_jokes(data: object) -> Union[List[str], None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                jokes_type_0 = cast(List[str], data)

                return jokes_type_0
            except:  # noqa: E722
                pass
            return cast(Union[List[str], None, Unset], data)

        jokes = _parse_jokes(d.pop("jokes", UNSET))

        def _parse_best_selected_joke(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        best_selected_joke = _parse_best_selected_joke(d.pop("best_selected_joke", UNSET))

        def _parse_messages(data: object) -> Union[List["BlogWriterAgentStateMessagesType0Item"], None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                messages_type_0 = []
                _messages_type_0 = data
                for messages_type_0_item_data in _messages_type_0:
                    messages_type_0_item = BlogWriterAgentStateMessagesType0Item.from_dict(messages_type_0_item_data)

                    messages_type_0.append(messages_type_0_item)

                return messages_type_0
            except:  # noqa: E722
                pass
            return cast(Union[List["BlogWriterAgentStateMessagesType0Item"], None, Unset], data)

        messages = _parse_messages(d.pop("messages", UNSET))

        ask_human = d.pop("ask_human", UNSET)

        blog_writer_agent_state = cls(
            subjects=subjects,
            jokes=jokes,
            best_selected_joke=best_selected_joke,
            messages=messages,
            ask_human=ask_human,
        )

        blog_writer_agent_state.additional_properties = d
        return blog_writer_agent_state

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
